@@ -13,16 +13,14 @@ The main entry point for RPC4Django. Usually, the user simply puts
 
 import logging
 import json
-from xml.dom.minidom import parseString
-from xml.parsers.expat import ExpatError
 from django.http import HttpResponse, Http404, HttpResponseForbidden
 from django.shortcuts import render_to_response
 from django.conf import settings
 from django.core.urlresolvers import reverse, NoReverseMatch, get_mod_func
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.importlib import import_module
-from rpcdispatcher import RPCDispatcher
-from __init__ import version
+from .rpcdispatcher import RPCDispatcher
+from .__init__ import version
 
 logger = logging.getLogger('rpc4django')
 
@@ -44,7 +42,7 @@ RESTRICT_RPCTEST = getattr(settings, 'RPC4DJANGO_RESTRICT_RPCTEST', False)
 HTTP_ACCESS_CREDENTIALS = getattr(settings,
                                   'RPC4DJANGO_HTTP_ACCESS_CREDENTIALS', False)
 HTTP_ACCESS_ALLOW_ORIGIN = getattr(settings,
-                                  'RPC4DJANGO_HTTP_ACCESS_ALLOW_ORIGIN', '')
+                                   'RPC4DJANGO_HTTP_ACCESS_ALLOW_ORIGIN', '')
 JSON_ENCODER = getattr(settings, 'RPC4DJANGO_JSON_ENCODER',
                        'django.core.serializers.json.DjangoJSONEncoder')
 
@@ -52,6 +50,7 @@ JSON_ENCODER = getattr(settings, 'RPC4DJANGO_JSON_ENCODER',
 # these will be scanned for @rpcmethod decorators
 APPS = getattr(settings, 'INSTALLED_APPS', [])
 
+
 def check_request_permission(request, request_format='xml'):
     '''
     Checks whether this user has permission to call a particular method
@@ -67,7 +66,7 @@ def check_request_permission(request, request_format='xml'):
 
     user = getattr(request, 'user', None)
     methods = dispatcher.list_methods()
-    method_name = dispatcher.get_method_name(request.raw_post_data, \
+    method_name = dispatcher.get_method_name(request.raw_post_data,
                                              request_format)
     response = True
 
@@ -76,37 +75,39 @@ def check_request_permission(request, request_format='xml'):
             # this is the method the user is calling
             # time to check the permissions
             if method.permission is not None:
-                logger.debug('Method "%s" is protected by permission "%s"' \
-                              %(method.name, method.permission))
+                logger.debug('Method "%s" is protected by permission "%s"'
+                             % (method.name, method.permission))
                 if user is None:
                     # user is only none if not using AuthenticationMiddleware
                     logger.warn('AuthenticationMiddleware is not enabled')
                     response = False
                 elif not user.has_perm(method.permission):
                     # check the permission against the permission database
-                    logger.info('User "%s" is NOT authorized' %(str(user)))
+                    logger.info('User "%s" is NOT authorized' % (str(user)))
                     response = False
                 else:
-                    logger.debug('User "%s" is authorized' %(str(user)))
+                    logger.debug('User "%s" is authorized' % (str(user)))
             elif method.login_required:
-                logger.debug('Method "%s" is protected by login_required'% method.name)
+                logger.debug('Method "%s" is protected by login_required'
+                             % method.name)
                 if user is None:
                     # user is only none if not using AuthenticationMiddleware
                     logger.warn('AuthenticationMiddleware is not enabled')
                     response = False
                 elif user.is_anonymous():
                     # ensure the user is logged in
-                    logger.info('User "%s" is NOT authorized' %(str(user)))
+                    logger.info('User "%s" is NOT authorized' % (str(user)))
                     response = False
                 else:
-                    logger.debug('User "%s" is authorized' %(str(user)))
+                    logger.debug('User "%s" is authorized' % (str(user)))
             else:
-                logger.debug('Method "%s" is unprotected' %(method.name))
+                logger.debug('Method "%s" is unprotected' % (method.name))
 
             break
 
     return response
 
+
 def is_xmlrpc_request(request):
     '''
     Determines whether this request should be served by XMLRPC or JSONRPC
@@ -130,18 +131,18 @@ def is_xmlrpc_request(request):
         return False
 
     if LOG_REQUESTS_RESPONSES:
-        logger.info('Unrecognized content-type "%s"' %conttype)
+        logger.info('Unrecognized content-type "%s"' % conttype)
         logger.info('Analyzing rpc request data to get content type')
 
     # analyze post data to see whether it is xml or json
     # this is slower than if the content-type was set properly
+    # checking JSON is safer than XML because of entity expansion
     try:
-        parseString(request.raw_post_data)
+        json.loads(request.raw_post_data)
+        return False
+    except ValueError:
         return True
-    except ExpatError:
-        pass
 
-    return False
 
 @csrf_exempt
 def serve_rpc_request(request):
@@ -157,11 +158,11 @@ def serve_rpc_request(request):
 
     '''
 
-    if request.method == "POST" and request.META.get('CONTENT_LENGTH', 0) > 0:
+    if request.method == "POST" and int(request.META.get('CONTENT_LENGTH', 0)) > 0:
         # Handle POST request with RPC payload
 
         if LOG_REQUESTS_RESPONSES:
-            logger.debug('Incoming request: %s' %str(request.raw_post_data))
+            logger.debug('Incoming request: %s' % str(request.raw_post_data))
 
         if is_xmlrpc_request(request):
             if RESTRICT_XML:
@@ -170,7 +171,7 @@ def serve_rpc_request(request):
             if not check_request_permission(request, 'xml'):
                 return HttpResponseForbidden()
 
-            resp = dispatcher.xmldispatch(request.raw_post_data, \
+            resp = dispatcher.xmldispatch(request.raw_post_data,
                                           request=request)
             response_type = 'text/xml'
         else:
@@ -180,12 +181,12 @@ def serve_rpc_request(request):
             if not check_request_permission(request, 'json'):
                 return HttpResponseForbidden()
 
-            resp = dispatcher.jsondispatch(request.raw_post_data, \
+            resp = dispatcher.jsondispatch(request.raw_post_data,
                                            request=request)
             response_type = 'application/json'
 
         if LOG_REQUESTS_RESPONSES:
-            logger.debug('Outgoing %s response: %s' %(response_type, resp))
+            logger.debug('Outgoing %s response: %s' % (response_type, resp))
 
         return HttpResponse(resp, response_type)
     elif request.method == 'OPTIONS':
@@ -198,14 +199,14 @@ def serve_rpc_request(request):
         response['Access-Control-Allow-Methods'] = 'POST, GET, OPTIONS'
         response['Access-Control-Max-Age'] = 0
         response['Access-Control-Allow-Credentials'] = \
-                        str(HTTP_ACCESS_CREDENTIALS).lower()
-        response['Access-Control-Allow-Origin']= HTTP_ACCESS_ALLOW_ORIGIN
+            str(HTTP_ACCESS_CREDENTIALS).lower()
+        response['Access-Control-Allow-Origin'] = HTTP_ACCESS_ALLOW_ORIGIN
 
         response['Access-Control-Allow-Headers'] = \
-                    request.META.get('HTTP_ACCESS_CONTROL_REQUEST_HEADERS', '')
+            request.META.get('HTTP_ACCESS_CONTROL_REQUEST_HEADERS', '')
 
         if LOG_REQUESTS_RESPONSES:
-            logger.debug('Outgoing HTTP access response to: %s' %(origin))
+            logger.debug('Outgoing HTTP access response to: %s' % (origin))
 
         return response
     else:
@@ -239,6 +240,13 @@ try:
 except NoReverseMatch:
     URL = ''
 
+try:
+    # Python2
+    basestring
+except NameError:
+    # Python3
+    basestring = str
+
 # resolve JSON_ENCODER to class if it's a string
 if isinstance(JSON_ENCODER, basestring):
     mod_name, cls_name = get_mod_func(JSON_ENCODER)
@@ -250,4 +258,4 @@ else:
 # instantiate the rpcdispatcher -- this examines the INSTALLED_APPS
 # for any @rpcmethod decorators and adds them to the callable methods
 dispatcher = RPCDispatcher(URL, APPS, RESTRICT_INTROSPECTION,
-        RESTRICT_OOTB_AUTH, json_encoder)
+                           RESTRICT_OOTB_AUTH, json_encoder)
